* linux-next: manual merge of the vfs-brauner tree with the origin tree
@ 2025-10-02 11:31 Mark Brown
0 siblings, 0 replies; 6+ messages in thread
From: Mark Brown @ 2025-10-02 11:31 UTC (permalink / raw)
To: Christian Brauner
Cc: Linus Torvalds, Linux Kernel Mailing List,
Linux Next Mailing List
[-- Attachment #1: Type: text/plain, Size: 1291 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got a conflict in:
include/linux/ipc_namespace.h
between commit:
18b19abc3709b ("Merge tag 'namespace-6.18-rc1' of git://git.kernel.org/pub/scm/linux/kernel/git/vfs/vfs")
from the origin tree and commit:
53195eef8fbf0 ("Merge branch 'namespace-6.18' into vfs.all")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
diff --cc include/linux/ipc_namespace.h
index 12faca29bbb9c,75bd73839b3b7..0000000000000
--- a/include/linux/ipc_namespace.h
+++ b/include/linux/ipc_namespace.h
@@@ -129,6 -129,9 +129,10 @@@ static inline int mq_init_ns(struct ipc
#endif
#if defined(CONFIG_IPC_NS)
++
+ extern struct ipc_namespace *copy_ipcs(u64 flags,
+ struct user_namespace *user_ns, struct ipc_namespace *ns);
+
static inline struct ipc_namespace *to_ipc_ns(struct ns_common *ns)
{
return container_of(ns, struct ipc_namespace, ns);
[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
^ permalink raw reply [flat|nested] 6+ messages in thread
* linux-next: manual merge of the vfs-brauner tree with the origin tree
@ 2026-03-13 12:59 Mark Brown
0 siblings, 0 replies; 6+ messages in thread
From: Mark Brown @ 2026-03-13 12:59 UTC (permalink / raw)
To: Christian Brauner
Cc: John Johansen, Linux Kernel Mailing List, Linux Next Mailing List,
NeilBrown
[-- Attachment #1: Type: text/plain, Size: 1433 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got a conflict in:
security/apparmor/apparmorfs.c
between commit:
8e135b8aee5a0 ("apparmor: fix race between freeing data and fs accessing it")
from the origin tree and commit:
5c6c7ae93236e ("Apparmor: Use simple_start_creating() / simple_done_creating()")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
diff --cc security/apparmor/apparmorfs.c
index 242c71b3fb6ef,32611e13dc3b0..0000000000000
--- a/security/apparmor/apparmorfs.c
+++ b/security/apparmor/apparmorfs.c
@@@ -364,22 -289,13 +358,17 @@@ static struct dentry *aafs_create(cons
}
error = __aafs_setup_d_inode(dir, dentry, mode, data, link, fops, iops);
+ simple_done_creating(dentry);
if (error)
- goto fail_dentry;
- inode_unlock(dir);
+ goto fail;
+
+ if (data)
+ aa_get_common_ref(data);
+
return dentry;
- fail_dentry:
- dput(dentry);
-
- fail_lock:
- inode_unlock(dir);
+ fail:
simple_release_fs(&aafs_mnt, &aafs_count);
-
return ERR_PTR(error);
}
[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
^ permalink raw reply [flat|nested] 6+ messages in thread
* linux-next: manual merge of the vfs-brauner tree with the origin tree
@ 2026-04-14 11:22 Mark Brown
0 siblings, 0 replies; 6+ messages in thread
From: Mark Brown @ 2026-04-14 11:22 UTC (permalink / raw)
To: Christian Brauner
Cc: Linus Torvalds, Linux Kernel Mailing List,
Linux Next Mailing List
[-- Attachment #1: Type: text/plain, Size: 1175 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got a conflict in:
fs/ext4/fsync.c
between commit:
fc825e513cd49 ("Merge tag 'vfs-7.1-rc1.bh.metadata' of git://git.kernel.org/pub/scm/linux/kernel/git/vfs/vfs")
from the origin tree and commits:
6e22726900ea5 ("Merge patch series "fs: Move metadata bh tracking from address_space"")
f2bab85781e80 ("Merge branch 'vfs-7.1.bh.metadata' into vfs.all")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
diff --combined fs/ext4/fsync.c
index 924726dcc85ff,abeb078a34647..0000000000000
--- a/fs/ext4/fsync.c
+++ b/fs/ext4/fsync.c
@@@ -100,7 -100,6 +100,7 @@@ static int ext4_fsync_nojournal(struct
return ret;
ret = ext4_sync_parent(inode);
+
if (test_opt(inode->i_sb, BARRIER))
*needs_barrier = true;
[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
^ permalink raw reply [flat|nested] 6+ messages in thread
* linux-next: manual merge of the vfs-brauner tree with the origin tree
@ 2026-04-15 10:43 Mark Brown
0 siblings, 0 replies; 6+ messages in thread
From: Mark Brown @ 2026-04-15 10:43 UTC (permalink / raw)
To: Christian Brauner
Cc: Linus Torvalds, Linux Kernel Mailing List,
Linux Next Mailing List
[-- Attachment #1: Type: text/plain, Size: 2561 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got conflicts in:
kernel/fork.c
kernel/nsproxy.c
between commit:
7c8a4671dc324 ("Merge tag 'vfs-7.1-rc1.mount.v2' of git://git.kernel.org/pub/scm/linux/kernel/git/vfs/vfs")
from the origin tree and commit:
8ee708daac8a2 ("Merge branch 'kernel-7.1.misc' into vfs.all")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
diff --combined kernel/fork.c
index 8c61c8dd43720,17497679cec70..0000000000000
--- a/kernel/fork.c
+++ b/kernel/fork.c
@@@ -2113,7 -2113,6 +2113,7 @@@ __latent_entropy struct task_struct *co
ftrace_graph_init_task(p);
rt_mutex_init_task(p);
+ raw_spin_lock_init(&p->blocked_lock);
lockdep_assert_irqs_enabled();
#ifdef CONFIG_PROVE_LOCKING
@@@ -2956,10 -2955,9 +2956,10 @@@ static inline bool clone3_stack_valid(s
static bool clone3_args_valid(struct kernel_clone_args *kargs)
{
/* Verify that no unknown flags are passed along. */
- if (kargs->flags & ~(CLONE_LEGACY_FLAGS | CLONE_CLEAR_SIGHAND |
- CLONE_INTO_CGROUP | CLONE_AUTOREAP | CLONE_NNP |
- CLONE_PIDFD_AUTOKILL | CLONE_EMPTY_MNTNS))
+ if (kargs->flags &
+ ~(CLONE_LEGACY_FLAGS | CLONE_CLEAR_SIGHAND |
+ CLONE_INTO_CGROUP | CLONE_AUTOREAP | CLONE_NNP |
+ CLONE_PIDFD_AUTOKILL | CLONE_EMPTY_MNTNS))
return false;
/*
@@@ -3110,7 -3108,7 +3110,7 @@@ static int check_unshare_flags(unsigne
{
if (unshare_flags & ~(CLONE_THREAD|CLONE_FS|CLONE_SIGHAND|
CLONE_VM|CLONE_FILES|CLONE_SYSVSEM|
- CLONE_NS_ALL|UNSHARE_EMPTY_MNTNS))
+ CLONE_NS_ALL | UNSHARE_EMPTY_MNTNS))
return -EINVAL;
/*
* Not implemented, but pretend it works if there is nothing
diff --combined kernel/nsproxy.c
index d9d3d5973bf52,71bf313087671..0000000000000
--- a/kernel/nsproxy.c
+++ b/kernel/nsproxy.c
@@@ -215,7 -215,7 +215,7 @@@ int unshare_nsproxy_namespaces(unsigne
u64 flags = unshare_flags;
int err = 0;
- if (!(flags & (CLONE_NS_ALL & ~CLONE_NEWUSER)))
+ if (!(flags & (CLONE_NS_ALL & ~(CLONE_NEWUSER | UNSHARE_EMPTY_MNTNS))))
return 0;
user_ns = new_cred ? new_cred->user_ns : current_user_ns();
[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
^ permalink raw reply [flat|nested] 6+ messages in thread
* linux-next: manual merge of the vfs-brauner tree with the origin tree
@ 2026-07-08 11:04 Mark Brown
0 siblings, 0 replies; 6+ messages in thread
From: Mark Brown @ 2026-07-08 11:04 UTC (permalink / raw)
To: Christian Brauner; +Cc: Linux Kernel Mailing List, Linux Next Mailing List
[-- Attachment #1: Type: text/plain, Size: 1712 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got conflicts in:
tools/testing/selftests/filesystems/Makefile
tools/testing/selftests/filesystems/.gitignore
between commit:
d943e68edc5cb ("selftests/filesystems: test O_TMPFILE creation on idmapped mounts")
from the origin tree and commit:
a21db4dcaf4ad ("selftests/filesystems: add ustat() coverage")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
diff --cc tools/testing/selftests/filesystems/.gitignore
index a78f894157de3,1bd53d54553c1..0000000000000
--- a/tools/testing/selftests/filesystems/.gitignore
+++ b/tools/testing/selftests/filesystems/.gitignore
@@@ -5,4 -5,4 +5,5 @@@ fclo
file_stressor
anon_inode_test
kernfs_test
+idmapped_tmpfile
+ ustat_test
diff --cc tools/testing/selftests/filesystems/Makefile
index a7ec2ba2dd833,bbdd40b167fac..0000000000000
--- a/tools/testing/selftests/filesystems/Makefile
+++ b/tools/testing/selftests/filesystems/Makefile
@@@ -1,8 -1,7 +1,8 @@@
# SPDX-License-Identifier: GPL-2.0
CFLAGS += $(KHDR_INCLUDES)
- TEST_GEN_PROGS := devpts_pts file_stressor anon_inode_test kernfs_test fclog
+ TEST_GEN_PROGS := devpts_pts file_stressor anon_inode_test kernfs_test fclog ustat_test
+TEST_GEN_PROGS += idmapped_tmpfile
TEST_GEN_PROGS_EXTENDED := dnotify_test
include ../lib.mk
[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
^ permalink raw reply [flat|nested] 6+ messages in thread
* linux-next: manual merge of the vfs-brauner tree with the origin tree
@ 2026-07-08 11:25 Mark Brown
0 siblings, 0 replies; 6+ messages in thread
From: Mark Brown @ 2026-07-08 11:25 UTC (permalink / raw)
To: Christian Brauner; +Cc: Linux Kernel Mailing List, Linux Next Mailing List
[-- Attachment #1: Type: text/plain, Size: 3928 bytes --]
Hi all,
Today's linux-next merge of the vfs-brauner tree got a conflict in:
fs/bpf_fs_kfuncs.c
between commit:
3f8c65b06fafc ("bpf: have bpf_real_data_inode() take a struct file")
from the origin tree and commit:
b4e124d168552 ("fs: Add bpf_sock_read_xattr() kfunc to read socket xattrs")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
diff --cc fs/bpf_fs_kfuncs.c
index f1863a891db64,9a4ea5c9b0c94..0000000000000
--- a/fs/bpf_fs_kfuncs.c
+++ b/fs/bpf_fs_kfuncs.c
@@@ -359,24 -360,52 +360,57 @@@ __bpf_kfunc int bpf_cgroup_read_xattr(s
}
#endif /* CONFIG_CGROUPS */
+ #ifdef CONFIG_NET
+ /**
+ * bpf_sock_read_xattr - read xattr of a socket's inode in sockfs
+ * @sock: socket to get xattr from
+ * @name__str: name of the xattr
+ * @value_p: output buffer of the xattr value
+ *
+ * Get xattr *name__str* of *sock* and store the output in *value_p*.
+ *
+ * For security reasons, only *name__str* with prefix "user." is allowed.
+ *
+ * Return: length of the xattr value on success, a negative value on error.
+ */
+ __bpf_kfunc int bpf_sock_read_xattr(struct socket *sock, const char *name__str,
+ struct bpf_dynptr *value_p)
+ {
+ struct bpf_dynptr_kern *value_ptr = (struct bpf_dynptr_kern *)value_p;
+ u32 value_len;
+ void *value;
+
+ /* Only allow reading "user.*" xattrs */
+ if (strncmp(name__str, XATTR_USER_PREFIX, XATTR_USER_PREFIX_LEN))
+ return -EPERM;
+
+ value_len = __bpf_dynptr_size(value_ptr);
+ value = __bpf_dynptr_data_rw(value_ptr, value_len);
+ if (!value)
+ return -EINVAL;
+
+ return sock_read_xattr(sock, name__str, value, value_len);
+ }
+ #endif /* CONFIG_NET */
+
/**
* bpf_real_inode - get the real inode backing a dentry
* @dentry: dentry to resolve
*
* If the dentry is on a union/overlay filesystem, return the underlying, real
* inode that hosts the data. Otherwise return the inode attached to the
* dentry itself.
*
- * Return: The real inode backing the dentry, or NULL for a negative dentry.
+ * Data resolution only applies to regular files. For a non-regular file (e.g.
+ * a device node, fifo or socket) on a union/overlay filesystem the overlay
+ * inode itself is returned; for any file on a non-union filesystem the inode
+ * attached to @file is returned.
+ *
+ * Return: The inode hosting @file's data, or NULL.
*/
-__bpf_kfunc struct inode *bpf_real_inode(struct dentry *dentry)
+__bpf_kfunc struct inode *bpf_real_data_inode(struct file *file)
{
- return d_real_inode(dentry);
+ return d_real_inode(file_dentry(file));
}
__bpf_kfunc_end_defs();
@@@ -389,7 -418,10 +423,10 @@@ BTF_ID_FLAGS(func, bpf_get_dentry_xattr
BTF_ID_FLAGS(func, bpf_get_file_xattr, KF_SLEEPABLE)
BTF_ID_FLAGS(func, bpf_set_dentry_xattr, KF_SLEEPABLE)
BTF_ID_FLAGS(func, bpf_remove_dentry_xattr, KF_SLEEPABLE)
-BTF_ID_FLAGS(func, bpf_real_inode, KF_SLEEPABLE | KF_RET_NULL)
+BTF_ID_FLAGS(func, bpf_real_data_inode, KF_SLEEPABLE | KF_RET_NULL)
+ #ifdef CONFIG_NET
+ BTF_ID_FLAGS(func, bpf_sock_read_xattr, KF_RCU)
+ #endif
BTF_KFUNCS_END(bpf_fs_kfunc_set_ids)
static int bpf_fs_kfuncs_filter(const struct bpf_prog *prog, u32 kfunc_id)
[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 488 bytes --]
^ permalink raw reply [flat|nested] 6+ messages in thread
end of thread, other threads:[~2026-07-08 11:25 UTC | newest]
Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2026-07-08 11:04 linux-next: manual merge of the vfs-brauner tree with the origin tree Mark Brown
-- strict thread matches above, loose matches on Subject: below --
2026-07-08 11:25 Mark Brown
2026-04-15 10:43 Mark Brown
2026-04-14 11:22 Mark Brown
@@@ -359,24 -360,52 +360,57 @@@ __bpf_kfunc int bpf_cgroup_read_xattr(s
/**
- * bpf_real_inode - get the real inode backing a dentry
- * @dentry: dentry to resolve
+ * bpf_real_data_inode - get the real inode hosting a file's data
+ * @file: file to resolve
*
@@@ -359,24 -360,52 +360,57 @@@ __bpf_kfunc int bpf_cgroup_read_xattr(s
*
- * If the dentry is on a union/overlay filesystem, return the underlying, real
- * inode that hosts the data. Otherwise return the inode attached to the
- * dentry itself.
+ * Resolve @file to the inode that hosts its data. For a regular file on a
+ * union/overlay filesystem this is the underlying (upper or lower) inode that
+ * stores the data, not the overlay inode.
*
2026-03-13 12:59 Mark Brown
2025-10-02 11:31 Mark Brown
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox